@@ -5,12 +5,73 @@ use warnings;
 use XSLoader;
 
 BEGIN {
-    our $VERSION = '0.230002';
+    our $VERSION = '0.240100';
     XSLoader::load('CommonMark', $VERSION);
 }
 
 package CommonMark;
 
+use Exporter 'import';
+our %EXPORT_TAGS = (
+    opt => [ qw(
+        OPT_DEFAULT
+        OPT_SOURCEPOS
+        OPT_HARDBREAKS
+        OPT_SAFE
+        OPT_NORMALIZE
+        OPT_VALIDATE_UTF8
+        OPT_SMART
+    ) ],
+    node => [ qw(
+        NODE_NONE
+        NODE_DOCUMENT
+        NODE_BLOCK_QUOTE
+        NODE_LIST
+        NODE_ITEM
+        NODE_CODE_BLOCK
+        NODE_HTML
+        NODE_PARAGRAPH
+        NODE_HEADER
+        NODE_HRULE
+        NODE_TEXT
+        NODE_SOFTBREAK
+        NODE_LINEBREAK
+        NODE_CODE
+        NODE_INLINE_HTML
+        NODE_EMPH
+        NODE_STRONG
+        NODE_LINK
+        NODE_IMAGE
+    ),
+    # libcmark 0.23
+    qw(
+        NODE_CUSTOM_BLOCK
+        NODE_CUSTOM_INLINE
+        NODE_HTML_BLOCK
+        NODE_HEADING
+        NODE_THEMATIC_BREAK
+        NODE_HTML_INLINE
+    ) ],
+    list => [ qw(
+        NO_LIST
+        BULLET_LIST
+        ORDERED_LIST
+    ) ],
+    delim => [ qw(
+        NO_DELIM
+        PERIOD_DELIM
+        PAREN_DELIM
+    ) ],
+    event => [ qw(
+        EVENT_NONE
+        EVENT_DONE
+        EVENT_ENTER
+        EVENT_EXIT
+    ) ],
+);
+Exporter::export_ok_tags();
+push(@{ $EXPORT_TAGS{all} }, @{ $EXPORT_TAGS{$_} }) for keys %EXPORT_TAGS;
+
 my @option_map = (
     sourcepos     => OPT_SOURCEPOS,
     hardbreaks    => OPT_HARDBREAKS,
@@ -101,19 +162,21 @@ sub create_code_block {
     return _add_literal($node, \%opts);
 }
 
-sub create_html {
+sub create_html_block {
     my (undef, %opts) = @_;
     my $node = CommonMark::Node->new(NODE_HTML);
     return _add_literal($node, \%opts);
 }
 
+sub create_html { &create_html_block; }
+
 sub create_paragraph {
     my (undef, %opts) = @_;
     my $node = CommonMark::Node->new(NODE_PARAGRAPH);
     return _add_children_or_text($node, \%opts);
 }
 
-sub create_header {
+sub create_heading {
     my (undef, %opts) = @_;
 
     my $node = CommonMark::Node->new(NODE_HEADER);
@@ -124,10 +187,14 @@ sub create_header {
     return _add_children_or_text($node, \%opts);
 }
 
-sub create_hrule {
+sub create_header { &create_heading; }
+
+sub create_thematic_break {
     return CommonMark::Node->new(NODE_HRULE);
 }
 
+sub create_hrule { &create_thematic_break; }
+
 sub create_text {
     my (undef, %opts) = @_;
     my $node = CommonMark::Node->new(NODE_TEXT);
@@ -148,12 +215,14 @@ sub create_code {
     return _add_literal($node, \%opts);
 }
 
-sub create_inline_html {
+sub create_html_inline {
     my (undef, %opts) = @_;
     my $node = CommonMark::Node->new(NODE_INLINE_HTML);
     return _add_literal($node, \%opts);
 }
 
+sub create_inline_html { &create_html_inline; }
+
 sub create_emph {
     my (undef, %opts) = @_;
     my $node = CommonMark::Node->new(NODE_EMPH);
@@ -178,6 +247,18 @@ sub create_image {
     return _add_link_opts($node, \%opts);
 }
 
+sub create_custom_block {
+    my (undef, %opts) = @_;
+    my $node = CommonMark::Node->new(NODE_CUSTOM_BLOCK);
+    return _add_custom_opts($node, \%opts);
+}
+
+sub create_custom_inline {
+    my (undef, %opts) = @_;
+    my $node = CommonMark::Node->new(NODE_CUSTOM_INLINE);
+    return _add_custom_opts($node, \%opts);
+}
+
 sub _add_children {
     my ($node, $opts) = @_;
 
@@ -232,6 +313,18 @@ sub _add_link_opts {
     return _add_children_or_text($node, $opts);
 }
 
+sub _add_custom_opts {
+    my ($node, $opts) = @_;
+
+    my $on_enter = $opts->{on_enter};
+    my $on_exit  = $opts->{on_exit};
+
+    $node->set_on_enter($on_enter) if defined($on_enter);
+    $node->set_on_exit($on_exit)   if defined($on_exit);
+
+    return _add_children_or_text($node, $opts);
+}
+
 package CommonMark::Node;
 
 sub render {
